/*
-------------------------------------------------------------------------------
    This file is a part of the Vst Preset Generator
    Copyright (C) 2007  Francois Mazen

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-------------------------------------------------------------------------------
  Name: parammanager.h
  Author: Francois Mazen
  Date: 28/05/07 16:25
  Description: header file of the ParamManager class
-------------------------------------------------------------------------------
*/

#ifndef PARAMMANAGER_H
#define PARAMMANAGER_H

#include <QAbstractTableModel>
#include <QStandardItemModel>

#include "vpgrandom.h"

class QString;

//random modes:
enum eRandomMode
{
     uniform = 0,
	 normal,
	 constant,
	 randomModeMax
};


struct paramStruct
{
 	   QString name;
 	   eRandomMode randomMode;
 	   float min; //UNIFORM_RANDOM
 	   float max; //UNIFORM_RANDOM
 	   float mid; //NORMAL_RANDOM
 	   float dev; //NORMAL_RANDOM
 	   float val; //CONSTANT
};
 	   
 	   

class ParamManager : public  QAbstractTableModel //QStandardItemModel
{
     Q_OBJECT

public:
	   ParamManager(QObject *parent = 0);
	   ~ParamManager();
	   
	   int rowCount(const QModelIndex &parent = QModelIndex()) const;
       int columnCount(const QModelIndex &parent = QModelIndex()) const;

	   //data display
       QVariant data(const QModelIndex &index, 
				     int role = Qt::DisplayRole) const;
       QVariant headerData(int section, Qt::Orientation orientation, 
                           int role = Qt::DisplayRole) const;
       
       //to edit data
       Qt::ItemFlags flags(const QModelIndex &index) const;
       bool setData(const QModelIndex &index, const QVariant &value,
                    int role = Qt::EditRole); 
                    
       void clear();
       void add(int index, paramStruct param);
       void setParamNb(int nb);
       
       float getRandomValue(int id_param);
       
private:
		//data
		QVector<paramStruct> paramList;
		
		VpgRandom *vpgRandom; //the random module
		

};

//-----------------------------------------------------------------------------




#endif //PARAMMANAGER_H
