/*
-------------------------------------------------------------------------------
    This file is a part of the Vst Preset Generator
    Copyright (C) 2007  Francois Mazen

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-------------------------------------------------------------------------------
  Name: paramvaluedelegate.cpp
  Author: Francois Mazen
  Date: 28/05/07 16:25
  Description: Object to edit a value in a table (see Qt's patern)
-------------------------------------------------------------------------------
*/

#include <QtGui>

#include "paramvaluedelegate.h"


//-----------------------------------------------------------------------------
//delegate float value class
//-----------------------------------------------------------------------------
ParamValueDelegate::ParamValueDelegate(QObject *parent) : QItemDelegate(parent)
{
}

//-----------------------------------------------------------------------------
QWidget *ParamValueDelegate::createEditor(QWidget *parent,
     const QStyleOptionViewItem &/* option */,
     const QModelIndex &/* index */) const
 {
     QDoubleSpinBox *editor = new QDoubleSpinBox(parent);
     editor->setRange(0,1);
     editor->setSingleStep(0.1);
     
     editor->installEventFilter(const_cast<ParamValueDelegate*>(this));

     return editor;
 }
 
//-----------------------------------------------------------------------------
void ParamValueDelegate::setEditorData(QWidget *editor,
                                     const QModelIndex &index) const
{
     QString rawData = index.model()->data(index, Qt::DisplayRole).toString();
     QStringList list = rawData.split(":");
     float value = list.last().toDouble();

     QDoubleSpinBox *spinBox = static_cast<QDoubleSpinBox*>(editor);
     spinBox->setValue(value);
}

//----------------------------------------------------------------------------- 
void ParamValueDelegate::setModelData(QWidget *editor, QAbstractItemModel *model,
                                    const QModelIndex &index) const
{
     QDoubleSpinBox *spinBox = static_cast<QDoubleSpinBox*>(editor);
     spinBox->interpretText();
     float value = spinBox->value();

     model->setData(index, value);
}

//-----------------------------------------------------------------------------
void ParamValueDelegate::updateEditorGeometry(QWidget *editor,
     const QStyleOptionViewItem &option, const QModelIndex &/* index */) const
{
     editor->setGeometry(option.rect);
}
